==> beagle-2.1.5.tar.gz: beagle-2.1.5/examples/GA/knapsack/knapsack/KnapsackMain.cpp <==
/*
 *  Open BEAGLE
 *  Copyright (C) 2001-2004 by Christian Gagne and Marc Parizeau
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  Contact:
 *  Laboratoire de Vision et Systemes Numeriques
 *  Departement de genie electrique et de genie informatique
 *  Universite Laval, Quebec, Canada, G1K 7P4
 *  http://vision.gel.ulaval.ca
 *
 */

/*!
 *  \file   KnapsackMain.cpp
 *  \brief  Implementation of the main routine for the Knapsack problem.
 *  \author Christian Gagne
 *  \author Marc Parizeau
 *  $Revision: 1.6 $
 *  $Date: 2004/04/25 23:12:22 $
 */

#include "beagle/GA.hpp"
#include "KnapsackEvalOp.hpp"

#include <cstdlib>
#include <iostream>
#include <stdexcept>
#include <vector>
#include <numeric>

using namespace std;
using namespace Beagle;

/*!
 *  \brief Main routine for the Knapsack problem.
 *  \param argc Number of arguments on the command-line.
 *  \param argv Arguments on the command-line.
 *  \return Return value of the program.
 *  \ingroup Knapsack
 */
int main(int argc, char** argv) {
  try {
    // 1. Build the system.
    System::Handle lSystem = new System;
    // 2. Build evaluation operator.
    KnapsackEvalOp::Handle lEvalOp = new KnapsackEvalOp;
    // 3. Instanciate the evolver.
    IntegerVector lEncoding(1, 24);
    GA::EvolverBitString::Handle lEvolver = new GA::EvolverBitString(lEvalOp, lEncoding);
    // 4. Initialize the vivarium with bitstring and MOEA fitness allocators
    GA::BitString::Alloc::Handle lBSAlloc = new GA::BitString::Alloc;
    FitnessMultiObj::Alloc::Handle lFitnessAlloc = new FitnessMultiObj::Alloc;
    Vivarium::Handle lVivarium = new Vivarium(lBSAlloc, lFitnessAlloc);
    // 5. Initialize the evolver and evolve the vivarium.
    lEvolver->initialize(lSystem, argc, argv);
    lEvolver->evolve(lVivarium);
  }
  catch(Exception& inException) {
    inException.terminate(cerr);
  }
  catch(std::exception& inException) {
    cerr << "Standard exception catched:" << endl << flush;
    cerr << inException.what() << endl << flush;
    return 1;
  }
  return 0;
}

==> beagle-2.2.0.tar.gz: beagle-2.2.0/examples/GA/knapsack/knapsack/KnapsackMain.cpp <==
/*
 *  Open BEAGLE
 *  Copyright (C) 2001-2004 by Christian Gagne and Marc Parizeau
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  Contact:
 *  Laboratoire de Vision et Systemes Numeriques
 *  Departement de genie electrique et de genie informatique
 *  Universite Laval, Quebec, Canada, G1K 7P4
 *  http://vision.gel.ulaval.ca
 *
 */

/*!
 *  \file   KnapsackMain.cpp
 *  \brief  Implementation of the main routine for the Knapsack problem.
 *  \author Christian Gagne
 *  \author Marc Parizeau
 *  $Revision: 1.7 $
 *  $Date: 2004/10/26 19:06:23 $
 */

#include "beagle/GA.hpp"
#include "KnapsackEvalOp.hpp"

#include <cstdlib>
#include <iostream>
#include <stdexcept>
#include <vector>
#include <numeric>

using namespace std;
using namespace Beagle;

/*!
 *  \brief Main routine for the Knapsack problem.
 *  \param argc Number of arguments on the command-line.
 *  \param argv Arguments on the command-line.
 *  \return Return value of the program.
 *  \ingroup Knapsack
 */
int main(int argc, char** argv) {
  try {
    // 1. Build the system.
    System::Handle lSystem = new System;
    // 2. Build evaluation operator.
    KnapsackEvalOp::Handle lEvalOp = new KnapsackEvalOp;
    // 3. Instanciate the evolver.
    const unsigned int lNumberOfBits=24;
    GA::EvolverBitString::Handle lEvolver = new GA::EvolverBitString(lEvalOp, lNumberOfBits);
    // 4. Initialize the vivarium with bitstring and MOEA fitness allocators
    GA::BitString::Alloc::Handle lBSAlloc = new GA::BitString::Alloc;
    FitnessMultiObj::Alloc::Handle lFitnessAlloc = new FitnessMultiObj::Alloc;
    Vivarium::Handle lVivarium = new Vivarium(lBSAlloc, lFitnessAlloc);
    // 5. Initialize the evolver and evolve the vivarium.
    lEvolver->initialize(lSystem, argc, argv);
    lEvolver->evolve(lVivarium);
  }
  catch(Exception& inException) {
    inException.terminate(cerr);
  }
  catch(std::exception& inException) {
    cerr << "Standard exception catched:" << endl << flush;
    cerr << inException.what() << endl << flush;
    return 1;
  }
  return 0;
}
